# eric7.DebugClients.Python.QProcessExtension

Module implementing a function to patch QProcess to support debugging of the process.

### Global Attributes

_debugClient

### Classes

QProcessWrapper | Wrapper class for *.QProcess.

### Functions

patchQProcess | Function to patch the QtCore module's QProcess.

## QProcessWrapper

Wrapper class for *.QProcess.

### Derived from

module.QProcess

### Class Attributes

_origQProcessStartDetached

### Class Methods

None

### Methods

QProcessWrapper | Constructor
__startDetached | Private method to start the detached process.
start | Public method to start the process.
startDetached | Public method to start the detached process.

### Static Methods

startDetachedStatic | Static method to start the detached process.

#### QProcessWrapper (Constructor)

QProcessWrapper(parent=None)

Constructor

#### QProcessWrapper.__startDetached

__startDetached(*args, **kwargs)

Private method to start the detached process.

This method patches the arguments such, that a debug client is started for the Python script. A Python script is assumed, if the program to be started contains the string 'python'.

args (list)
  arguments of the start call
kwargs (dict)
  keyword arguments of the start call

Return:
  flag indicating a successful start

Return Type:
  bool

#### QProcessWrapper.start

start(*args, **kwargs)

Public method to start the process.

This method patches the arguments such, that a debug client is started for the Python script. A Python script is assumed, if the program to be started contains the string 'python'.

args (list)
  arguments of the start call
kwargs (dict)
  keyword arguments of the start call

#### QProcessWrapper.startDetached

startDetached(*args, **kwargs)

Public method to start the detached process.

This method patches the arguments such, that a debug client is started for the Python script. A Python script is assumed, if the program to be started contains the string 'python'.

args (list)
  arguments of the start call
kwargs (dict)
  keyword arguments of the start call

Return:
  flag indicating a successful start

Return Type:
  bool

#### QProcessWrapper.startDetachedStatic (static)

startDetachedStatic(**kwargs)

Static method to start the detached process.

This method patches the arguments such, that a debug client is started for the Python script. A Python script is assumed, if the program to be started contains the string 'python'.

args (list)
  arguments of the start call
kwargs (dict)
  keyword arguments of the start call

Return:
  flag indicating a successful start

Return Type:
  bool

Up

## patchQProcess

patchQProcess(module, debugClient)

Function to patch the QtCore module's QProcess.

module (module)
  reference to the imported module to be patched
debugClient (DebugClient)
  reference to the debug client object

Up